@@ -3,6 +3,7 @@ import importlib
 import os
 import sys
 from pathlib import Path
+from typing import Optional
 
 import grpc
 from google.protobuf.json_format import Parse, MessageToJson
@@ -10,9 +11,10 @@ from google.protobuf.json_format import Parse, MessageToJson
 sys.path.append(str(os.path.dirname(__file__)))
 
 name = 'locapip'
-version = __version__ = '0.1.7'
+version = __version__ = '0.1.9'
+
 server = grpc.aio.server()
-config = {}
+server_task: Optional[asyncio.Task] = None
 
 
 def import_package(path: str):
@@ -22,7 +24,10 @@ def import_package(path: str):
     for p in os.listdir(path):
         if p.endswith('.py') and (Path(path) / p).is_file():
             print(f'import  {Path(path) / p}')
-            importlib.import_module(p[:-3])
+            if p[:-3] in globals():
+                importlib.reload(globals()[p[:-3]])
+            else:
+                importlib.import_module(p[:-3])
 
 
 def import_package_test():
@@ -30,13 +35,23 @@ def import_package_test():
     print()
 
 
-async def serve(port: int) -> None:
+async def _serve(port: int):
     import_package_test()
     server.add_insecure_port(f'[::]:{port}')
     await server.start()
     await server.wait_for_termination()
 
 
+def serve(port: int, run_until_complete=True):
+    if run_until_complete:
+        asyncio.get_event_loop().run_until_complete(_serve(port))
+    else:
+        global server_task
+        if not server_task:
+            server_task.cancel()
+        server_task = asyncio.ensure_future(_serve(port))
+
+
 pb = {}
 stub = {}
 py_request = {}
