@@ -1,4 +1,3 @@
-import asyncio
 import logging
 from pathlib import Path
 
@@ -19,7 +18,7 @@ def main(port: int, proto):
             locapip.import_package(path)
 
     logging.basicConfig(level=logging.INFO)
-    asyncio.get_event_loop().run_until_complete(locapip.serve(port))
+    locapip.serve(port)
 
 
 if __name__ == "__main__":
